# -*- coding: utf-8 -*-
'''
custom stats module for reinforcement learning
==============================================

This module provides custom statistics classes.

Classes
-------
    WarfarinStats: a statistic class for warfarin analysis.


'''

from .warfarin_stats import WarfarinStats  # noqa: W0611
